@@ -101,8 +101,18 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
                                     csc=dict(next_hop="1.2.3.4"),
                                 ),
                                 route_target=dict(
-                                    export="10.12.0.1:20",
-                                    import_config="10.0.0.1:30",
+                                    exports=[
+                                        dict(
+                                            rt_value="10.12.0.1:20",
+                                            stitching=False,
+                                        ),
+                                    ],
+                                    imports=[
+                                        dict(
+                                            rt_value="10.0.0.1:30",
+                                            stitching=False,
+                                        ),
+                                    ],
                                 ),
                                 mdt=dict(
                                     auto_discovery=dict(
@@ -141,8 +151,22 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
                                     csc=dict(next_hop="1.2.3.4"),
                                 ),
                                 route_target=dict(
-                                    export="10.12.0.1:20",
-                                    import_config="10.0.0.1:10",
+                                    exports=[
+                                        dict(
+                                            rt_value="10.12.0.1:20",
+                                            stitching=True,
+                                        ),
+                                    ],
+                                    imports=[
+                                        dict(
+                                            rt_value="10.0.0.1:10",
+                                            stitching=False,
+                                        ),
+                                        dict(
+                                            rt_value="10.0.0.1:30",
+                                            stitching=True,
+                                        ),
+                                    ],
                                 ),
                             ),
                         ],
@@ -157,11 +181,12 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
             "export map testing-map",
             "import map import-map",
             "inter-as-hybrid csc next-hop 1.2.3.4",
-            "route-target export 10.12.0.1:20",
+            "route-target export 10.12.0.1:20 stitching",
             "route-target import 10.0.0.1:10",
+            "route-target import 10.0.0.1:30 stitching",
         ]
         result = self.execute_module(changed=True)
-        self.assertEqual((result["commands"]), (commands))
+        self.assertEqual(sorted((result["commands"])), sorted((commands)))
 
     def test_ios_vrf_address_family_replaced(self):
         """Test the replaced state of the ios_vrf_address_family module."""
@@ -198,8 +223,18 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
                                     csc=dict(next_hop="1.2.3.4"),
                                 ),
                                 route_target=dict(
-                                    export="10.12.0.1:20",
-                                    import_config="10.0.0.1:10",
+                                    exports=[
+                                        dict(
+                                            rt_value="10.12.0.1:20",
+                                            stitching=False,
+                                        ),
+                                    ],
+                                    imports=[
+                                        dict(
+                                            rt_value="10.0.0.1:10",
+                                            stitching=False,
+                                        ),
+                                    ],
                                 ),
                             ),
                         ],
@@ -218,7 +253,8 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
             "route-target import 10.0.0.1:10",
         ]
         result = self.execute_module(changed=True)
-        self.assertEqual((result["commands"]), (commands))
+        print(result["commands"])
+        self.assertEqual(sorted((result["commands"])), sorted((commands)))
 
     def test_ios_vrf_address_family_replaced_idempotent(self):
         """Test the idempotent nature of the ios_vrf_address_family module in replaced state."""
@@ -254,8 +290,18 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
                                     csc=dict(next_hop="1.2.3.4"),
                                 ),
                                 route_target=dict(
-                                    export="10.12.0.1:20",
-                                    import_config="10.0.0.1:10",
+                                    exports=[
+                                        dict(
+                                            rt_value="10.12.0.1:20",
+                                            stitching=False,
+                                        ),
+                                    ],
+                                    imports=[
+                                        dict(
+                                            rt_value="10.0.0.1:10",
+                                            stitching=False,
+                                        ),
+                                    ],
                                 ),
                             ),
                         ],
@@ -355,7 +401,7 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
             "inter-as-hybrid csc next-hop 1.2.3.4",
         ]
         result = self.execute_module(changed=False)
-        self.assertEqual((result["rendered"]), (commands))
+        self.assertEqual(sorted(result["rendered"]), sorted(commands))
 
     def test_ios_vrf_address_family_parsed(self):
         """Test the parsed state of the ios_vrf_address_family module."""
@@ -405,3 +451,186 @@ class TestIosVrfAddressFamilyModule(TestIosModule):
         ]
 
         self.assertEqual(parsed_list, result["parsed"])
+
+    def test_ios_vrf_address_family_parsed_mdt_bug(self):
+        """Test parsing of various MDT configurations reported in a bug."""
+        run_cfg = dedent(
+            """\
+            vrf definition DNB_Multicast_mottak
+             rd 201627:3814
+             !
+             address-family ipv4
+              mdt auto-discovery mldp
+              mdt strict-rpf interface
+              mdt partitioned mldp p2mp
+              mdt data mpls mldp 255
+              mdt overlay use-bgp
+             exit-address-family
+            !
+            """,
+        )
+        set_module_args(dict(running_config=run_cfg, state="parsed"))
+        result = self.execute_module(changed=False)
+        expected_parsed = [
+            {
+                "name": "DNB_Multicast_mottak",
+                "address_families": [
+                    {
+                        "afi": "ipv4",
+                        "safi": "unicast",
+                        "mdt": {
+                            "auto_discovery": {"mldp": True},
+                            "strict_rpf": {"interface": True},
+                            "partitioned": {"mldp": {"p2mp": True}},
+                            "data": {"mpls": {"mldp": 255}},
+                            "overlay": {"use_bgp": {"set": True}},
+                        },
+                    },
+                ],
+            },
+        ]
+        self.assertEqual(result["parsed"], expected_parsed)
+
+    def test_ios_vrf_address_family_merged_mdt(self):
+        """Test adding a new MDT config to an existing VRF AF in merged state."""
+        run_cfg = dedent(
+            """\
+            vrf definition DNB_Multicast_mottak
+             rd 201627:3814
+             !
+             address-family ipv4
+              mdt strict-rpf interface
+              mdt data mpls mldp 255
+             exit-address-family
+            !
+            """,
+        )
+        self.get_config.return_value = run_cfg
+
+        set_module_args(
+            dict(
+                config=[
+                    {
+                        "name": "DNB_Multicast_mottak",
+                        "address_families": [
+                            {
+                                "afi": "ipv4",
+                                "safi": "unicast",
+                                "mdt": {
+                                    "strict_rpf": {"interface": True},
+                                    "data": {"mpls": {"mldp": 255}},
+                                    "log_reuse": True,
+                                },
+                            },
+                        ],
+                    },
+                ],
+                state="merged",
+            ),
+        )
+        expected_commands = [
+            "vrf definition DNB_Multicast_mottak",
+            "address-family ipv4 unicast",
+            "mdt log-reuse",
+        ]
+        result = self.execute_module(changed=True)
+        self.assertEqual(result["commands"], expected_commands)
+
+    def test_ios_vrf_address_family_replaced_mdt(self):
+        """Test replacing MDT config on an existing VRF AF in replaced state."""
+        run_cfg = dedent(
+            """\
+            vrf definition DNB_Multicast_mottak
+             rd 201627:3814
+             !
+             address-family ipv4
+              mdt auto-discovery mldp
+              mdt overlay use-bgp
+             exit-address-family
+            !
+            """,
+        )
+        self.get_config.return_value = run_cfg
+
+        set_module_args(
+            dict(
+                config=[
+                    {
+                        "name": "DNB_Multicast_mottak",
+                        "address_families": [
+                            {
+                                "afi": "ipv4",
+                                "safi": "unicast",
+                                "mdt": {
+                                    "data": {"mpls": {"mldp": 100}},
+                                    "strict_rpf": {"interface": True},
+                                },
+                            },
+                        ],
+                    },
+                ],
+                state="replaced",
+            ),
+        )
+        expected_commands = [
+            "vrf definition DNB_Multicast_mottak",
+            "address-family ipv4 unicast",
+            "no mdt auto-discovery mldp",
+            "no mdt overlay use-bgp",
+            "mdt data mpls mldp 100",
+            "mdt strict-rpf interface",
+        ]
+        result = self.execute_module(changed=True)
+        self.assertEqual(sorted(result["commands"]), sorted(expected_commands))
+
+    def test_ios_vrf_address_family_overridden_mdt(self):
+        """Test overriding MDT config on an existing VRF AF in overridden state."""
+        run_cfg = dedent(
+            """\
+            vrf definition DNB_Multicast_mottak
+             rd 201627:3814
+             !
+             address-family ipv4
+              mdt auto-discovery mldp
+              mdt strict-rpf interface
+              mdt partitioned mldp p2mp
+              mdt data mpls mldp 255
+              mdt overlay use-bgp
+             exit-address-family
+            !
+            """,
+        )
+        self.get_config.return_value = run_cfg
+
+        set_module_args(
+            dict(
+                config=[
+                    {
+                        "name": "DNB_Multicast_mottak",
+                        "address_families": [
+                            {
+                                "afi": "ipv4",
+                                "safi": "unicast",
+                                "mdt": {
+                                    "log_reuse": True,
+                                },
+                            },
+                        ],
+                    },
+                ],
+                state="overridden",
+            ),
+        )
+
+        expected_commands = [
+            "vrf definition DNB_Multicast_mottak",
+            "address-family ipv4 unicast",
+            "no mdt auto-discovery mldp",
+            "no mdt strict-rpf interface",
+            "no mdt partitioned mldp p2mp",
+            "no mdt data mpls mldp 255",
+            "no mdt overlay use-bgp",
+            "mdt log-reuse",
+        ]
+        result = self.execute_module(changed=True)
+        self.assertEqual(sorted(result["commands"]), sorted(expected_commands))
